==> manydhcp2.5.2.tar.bz2: manydhcp/update.php <==
<?php
  ///////////////////////////////////////////////////
  //Управление серверами DHCP,
  //обновление
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("lang/".$lang."/".$lang.".php")) include "lang/".$lang."/".$lang.".php";
     else include "lang/ru/ru.php";

  require_once "utils/top_update.php";
  if(!isset($button)) $button = $TEXT['btn_inst'];
  if(!isset($action)) $action = "update_run.php";
?>
<table align="center" width="100%" border="0" cellspacing="0" cellpadding="20">
<tr><td>&nbsp;</td></tr>
</table>
<table align="center" width="65%" border="0" cellspacing="0" cellpadding="0">
 <tr>
  <td width="16">&nbsp;</td>
  <td></td>
  <td width="16">&nbsp;</td>
 </tr>
 <tr>
  <td class="osn_top_r"></td>
  <td class="osn_top"></td>
  <td class="osn_top_l"></td>
 </tr>
 <tr>
  <td class="osn_left">&nbsp;</td>
  <td class="osn_center">
   <table width="100%" border="0" cellspacing="0" cellpadding="30">
   <tr>
    <td class="osn_center">
    <form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
    <table align="center">
     <tr><td align="center" class="zagolovok"><?php echo $TEXT['update-title']; ?></td></tr>
     <tr><td class="upd"><?php echo $TEXT['update-help']; ?></td></tr>
    </table>
    <br />
    <table align="center" border="0">
     <tr><td align="right" class="add_field_op"><?php echo $TEXT['install-srv']; ?></td><td class="useraddedit" title="<?php echo $TEXT['global-mandatory']; ?>"><input size=30 maxlength=50 class=add_field type=text name=srv value="localhost"></td></tr>
     <tr><td align="right" class="add_field_op"><?php echo $TEXT['update-db']; ?></td><td class="useraddedit" title="<?php echo $TEXT['global-mandatory']; ?>"><input size=30 maxlength=50 class=add_field type=text name=dbname value="db_manydhcp"></td></tr>
     <tr><td align="right" class="add_field_op"><?php echo $TEXT['install-usr']; ?></td><td class="useraddedit" title="<?php echo $TEXT['global-mandatory']; ?>"><input size=30 maxlength=30 class=add_field type=text name=usr value="root"></td></tr>
     <tr><td align="right" class="add_field_op"><?php echo $TEXT['install-pswd']; ?></td><td class="useraddedit" title="<?php echo $TEXT['global-mandatory']; ?>"><input size=30 maxlength=100 class=add_field type=password name=pswd ></td></tr>
     <tr><td align="right" class="add_field_op"><?php echo $TEXT['update-vers']; ?></td><td class="upd_var" >
     <input type=radio name=vers value=1><?php echo $TEXT['1112-1122']; ?><br />
     <input type=radio name=vers value=2><?php echo $TEXT['202-212']; ?><br />
     <input type=radio name=vers value=3><?php echo $TEXT['212-222']; ?><br />
     <input type=radio name=vers value=4 checked><?php echo $TEXT['222-232']; ?>
     </td></tr>
     <tr><td>&nbsp;</td><td><input class=button type=submit value='<?php echo $button; ?>'></td></tr>
    </table>
   </form>
  </td>
 </tr>
</table>                    
   </td>
     <td class="osn_right">&nbsp;</td>
   </tr>
   <tr>
    <td class="osn_bottom_r"></td>
    <td class="osn_bottom"></td>
    <td class="osn_bottom_l"></td>
   </tr>
 </table>
</body>
</html>

==> manydhcp2.7.2.tar.bz2: manydhcp/update.php <==
<?php
  ///////////////////////////////////////////////////
  //Управление серверами DHCP,
  //обновление
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("lang/".$lang."/".$lang.".php")) {include "lang/".$lang."/".$lang.".php";}
     else {include "lang/ru/ru.php";}

  require_once "utils/top_update.php";
  $button = $TEXT['btn_inst'];
  $action = "update_run.php";
?>
<table align="center" width="100%" border="0" cellspacing="0" cellpadding="20">
<tr><td>&nbsp;</td></tr>
</table>
<table align="center" width="65%" border="0" cellspacing="0" cellpadding="0">
 <tr>
  <td width="16">&nbsp;</td>
  <td></td>
  <td width="16">&nbsp;</td>
 </tr>
 <tr>
  <td class="osn_top_r"></td>
  <td class="osn_top"></td>
  <td class="osn_top_l"></td>
 </tr>
 <tr>
  <td class="osn_left">&nbsp;</td>
  <td class="osn_center">
   <table width="100%" border="0" cellspacing="0" cellpadding="30">
   <tr>
    <td class="osn_center">
    <form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
    <table align="center">
     <tr><td align="center" class="zagolovok"><?php echo $TEXT['update-title']; ?></td></tr>
     <tr><td class="upd"><?php echo $TEXT['update-help']; ?></td></tr>
    </table>
    <br />
    <table align="center" border="0">
     <tr><td align="right" class="add_field_op"><?php echo $TEXT['install-srv']; ?></td><td class="useraddedit" title="<?php echo $TEXT['global-mandatory']; ?>"><input size=30 maxlength=50 class=add_field type=text name=srv value="localhost"></td></tr>
     <tr><td align="right" class="add_field_op"><?php echo $TEXT['update-db']; ?></td><td class="useraddedit" title="<?php echo $TEXT['global-mandatory']; ?>"><input size=30 maxlength=50 class=add_field type=text name=dbname value="db_manydhcp"></td></tr>
     <tr><td align="right" class="add_field_op"><?php echo $TEXT['install-usr']; ?></td><td class="useraddedit" title="<?php echo $TEXT['global-mandatory']; ?>"><input size=30 maxlength=30 class=add_field type=text name=usr value="root"></td></tr>
     <tr><td align="right" class="add_field_op"><?php echo $TEXT['install-pswd']; ?></td><td class="useraddedit" title="<?php echo $TEXT['global-mandatory']; ?>"><input size=30 maxlength=100 class=add_field type=password name=pswd ></td></tr>
     <tr><td align="right" class="add_field_op"><?php echo $TEXT['update-vers']; ?></td><td class="upd_var" >
     <input type=radio name=vers value=1><?php echo $TEXT['1112-1122']; ?><br />
     <input type=radio name=vers value=2><?php echo $TEXT['202-212']; ?><br />
     <input type=radio name=vers value=3><?php echo $TEXT['212-222']; ?><br />
     <input type=radio name=vers value=4 checked><?php echo $TEXT['222-232']; ?>
     </td></tr>
     <tr><td>&nbsp;</td><td><input class=button type=submit value='<?php echo $button; ?>'></td></tr>
    </table>
   </form>
  </td>
 </tr>
</table>                    
   </td>
     <td class="osn_right">&nbsp;</td>
   </tr>
   <tr>
    <td class="osn_bottom_r"></td>
    <td class="osn_bottom"></td>
    <td class="osn_bottom_l"></td>
   </tr>
 </table>
</body>
</html>
